@@ -3,7 +3,7 @@ use Catmandu::Sane;
 use Catmandu::Util qw(xml_escape is_different :array :is);
 use Moo;
 
-our $VERSION = '1.30';
+our $VERSION = '1.31';
 
 with 'Catmandu::Exporter', 'Catmandu::Exporter::MARC::Base', 'Catmandu::Buffer';
 
@@ -13,7 +13,21 @@ has skip_empty_subfields => (is => 'ro' , default => sub { 1 });
 has collection           => (is => 'ro' , default => sub { 1 });
 has xml_declaration      => (is => 'ro' , default => sub { 1 });
 has pretty               => (is => 'rw' , default => sub { 0 });
-has _n                   => (is => 'rw' , default => sub { 0 });
+
+sub BUILD {
+    my ($self, $args) = @_;
+
+    if ($self->xml_declaration) {
+        $self->buffer_add( Catmandu::Util::xml_declaration );
+    }
+
+    if ($self->collection) {
+        $self->_line(0,'<marc:collection xmlns:marc="http://www.loc.gov/MARC21/slim">');
+    }
+
+    $self->fh->print( join('', @{ $self->buffer } ) );
+    $self->clear_buffer;
+}
 
 sub _line {
     my ($self, $indent, $line) = @_;
@@ -28,18 +42,6 @@ sub _line {
 sub add {
     my ($self, $data) = @_;
 
- 	if ($self->_n == 0) {
-    	if ($self->xml_declaration) {
-            $self->buffer_add( Catmandu::Util::xml_declaration );
-    	}
-
-    	if ($self->collection) {
-            $self->_line(0,'<marc:collection xmlns:marc="http://www.loc.gov/MARC21/slim">');
-    	}
-
-    	$self->_n(1);
-    }
-
     my $indent = $self->collection ? 1 : 0;
 
     if ($self->record_format eq 'MARC-in-JSON') {
